@@ -62,21 +62,24 @@ class CIRun:
         analysis_type = self._settings.analysis_type
         commit_id = self._settings.commit
         branch_name = self._settings.branch
+        pipeline_id = self._settings.get("pipeline_id")
         job_name = self._settings.get("job_name")
 
-        if job_name is None:
-            return self.create(analysis_type, commit_id, branch_name)
-
-        return self.create(analysis_type, commit_id, branch_name, job_name)
+        return self.create(analysis_type, commit_id, branch_name, pipeline_id, job_name)
 
     @staticmethod
-    def create(analysis_type, commit_id, branch_name, job_name=None):
+    def create(analysis_type, commit_id, branch_name, pipeline_id=None, job_name=None):
 
-        """Use the branch name, commit sha, and analysis type to create a new ciRun instance"""
+        """Use the branch name, commit sha, analysis type, job_name,
+        and pipeline id to create a new ciRun instance"""
 
         api_client = get_client()
         create_properties = CIRunCreateProps(
-            branch=branch_name, commit_id=commit_id, type=analysis_type, name=job_name
+            branch=branch_name,
+            commit_id=commit_id,
+            type=analysis_type,
+            pipeline_id=pipeline_id,
+            name=job_name,
         )
 
         response = None
